@@ -1,6 +1,6 @@
 /*
     Standard MIDI File component
-    Copyright (C) 2006-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2024, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     Based on midifile.c by Tim Thompson, M.Czeiszperger and Greg Lee
 
@@ -141,7 +141,7 @@ public:
     Q_DECL_DEPRECATED QTextCodec* getTextCodec();
     Q_DECL_DEPRECATED void setTextCodec(QTextCodec *codec);
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted for a SMF read or write error
      * @param errorStr Error string
